==> freecycle-0.6alpha.tar.bz2: freecycle/src/keypressglobaleventfilter.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Predrag Viceic                                  *
 *   viceic@net2000.ch                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "keypressglobaleventfilter.h"

KeyPressGlobalEventFilter::KeyPressGlobalEventFilter(QObject *parent, const char *name)
 : QObject(parent, name)
{
}


KeyPressGlobalEventFilter::~KeyPressGlobalEventFilter()
{
}




/*!
    \fn KeyPressGlobalEventFilter::eventFilter( QObject *o, QEvent *e )
 */
bool KeyPressGlobalEventFilter::eventFilter( QObject * /*o*/, QEvent *e )
{
    if ( e->type() == QEvent::KeyPress ) {
            // special processing for key press
            QKeyEvent *k = (QKeyEvent *)e;
            if ( k->key() == Key_Space ) {
                return TRUE; // eat event
            }else{
                return FALSE;
            }
        } else {
            // standard event processing
            return FALSE;
        }
}

==> freecycle-0.51alpha.tar.bz2: freecycle/src/keypressglobaleventfilter.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Predrag Viceic                                  *
 *   viceic@net2000.ch                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "keypressglobaleventfilter.h"

KeyPressGlobalEventFilter::KeyPressGlobalEventFilter(QObject *parent, const char *name)
 : QObject(parent, name)
{
}


KeyPressGlobalEventFilter::~KeyPressGlobalEventFilter()
{
}




/*!
    \fn KeyPressGlobalEventFilter::eventFilter( QObject *o, QEvent *e )
 */
bool KeyPressGlobalEventFilter::eventFilter( QObject *o, QEvent *e )
{
    if ( e->type() == QEvent::KeyPress ) {
            // special processing for key press
            QKeyEvent *k = (QKeyEvent *)e;
            if ( k->key() == Key_Space ) {
                return TRUE; // eat event
            }else{
                return FALSE;
            }
        } else {
            // standard event processing
            return FALSE;
        }
}
